#include <lpc214x.h>
#include "tim.h"
#include "lcd.h"
#include "stdio.h" 
#include "string.h"

void initClocks(void); 
void initTimer0(void);
__irq void timer0ISR(void);

int main(void)
{
	init_lcd();
//	lcd_clear();
   initClocks(); 			// Initialize PLL to setup clocks
   initTimer0(); 			// Initialize Timer0
	  IO0DIR |= (1<<8); //(1<<10);	

   T0TCR = (1<<0); 		// Enable timer
   while(1); 					// Infinite Idle Loop
}


void initTimer0(void)
{
	T0CTCR = 0x0;			//Set Timer Mode
	T0PR = 6233-1;//60000-1; //7500-1; 	//Increment T0TC at every 60000 clock cycles
										//60000 clock cycles @60Mhz = 1 mS
	
	T0MR0 = 500-1; 	//Zero Indexed Count-hence subtracting 1
	T0MCR = (1<<0) | (1<<1);//Set bit0 & bit1 to Interrupt & Reset TC on MR0  

	VICVectAddr4 = (unsigned )timer0ISR; //Pointer Interrupt Function (ISR)
	VICVectCntl4 = (1<<5) | 4; 	//(bit 5 = 1)->to enable Vectored IRQ slot
															//bit[4:0]) -> this the source number - here its timer0 which has VIC channel mask # as 4
	VICIntEnable = (1<<4);	// Enable timer0 interrupt
	
	T0TCR = (1<<1); 				// Reset Timer
}
//7000-1=2*50m=10hz
//7500-1=2.1*50m=9.52hz
//2.08*50m=9.61
//2.07*50m=9.66
//2.079*50m=9.62
//2.076*50m=9.633
//2.075*50m=9.638


__irq void timer0ISR(void)
{
	long int readVal;
	readVal = T0IR; 		// Read current IR value	
	IO0PIN ^= (1<<8); 	// Toggle LED at Pin P0.10
	T0IR = readVal; 		// Write back to IR to clear Interrupt Flag
	VICVectAddr = 0x0; 	// End of interrupt execution
}

void initClocks(void)
{
	PLL0CON = 0x01;   //Enable PLL
	PLL0CFG = 0x24;   //Multiplier and divider setup
	PLL0FEED = 0xAA;  //Feed sequence
	PLL0FEED = 0x55;
	
	while(!(PLL0STAT & 0x00000400)); //is locked?
		
	PLL0CON = 0x03;  //Connect PLL after PLL is locked
	PLL0FEED = 0xAA; //Feed sequence
	PLL0FEED = 0x55;
	VPBDIV = 0x01;   // PCLK is same as CCLK i.e.60 MHz
}

void delay2(int count)
{
  int j=0,i=0;

  for(j=0;j<count;j++)
  {
    /* At 60Mhz, the below loop introduces
    delay of 10 us */
    for(i=0;i<35;i++);

  }
}
